@@ -4,7 +4,7 @@
 
     Test the build process with manpage builder with the test root.
 
-    :copyright: Copyright 2007-2019 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
@@ -17,9 +17,9 @@ from sphinx.config import Config
 @pytest.mark.sphinx('man')
 def test_all(app, status, warning):
     app.builder.build_all()
-    assert (app.outdir / 'sphinxtests.1').exists()
+    assert (app.outdir / '1' / 'sphinxtests.1').exists()
 
-    content = (app.outdir / 'sphinxtests.1').text()
+    content = (app.outdir / '1' / 'sphinxtests.1').read_text()
     assert r'\fBprint \fP\fIi\fP\fB\en\fP' in content
     assert r'\fBmanpage\en\fP' in content
 
@@ -30,10 +30,17 @@ def test_all(app, status, warning):
     assert 'Footnotes' not in content
 
 
+@pytest.mark.sphinx('man', testroot='basic',
+                    confoverrides={'man_make_section_directory': False})
+def test_man_make_section_directory(app, status, warning):
+    app.build()
+    assert (app.outdir / 'python.1').exists()
+
+
 @pytest.mark.sphinx('man', testroot='directive-code')
 def test_captioned_code_block(app, status, warning):
     app.builder.build_all()
-    content = (app.outdir / 'python.1').text()
+    content = (app.outdir / '1' / 'python.1').read_text()
 
     assert ('.sp\n'
             'caption \\fItest\\fP rb\n'
@@ -64,5 +71,5 @@ def test_default_man_pages():
 @pytest.mark.sphinx('man', testroot='markup-rubric')
 def test_rubric(app, status, warning):
     app.build()
-    content = (app.outdir / 'python.1').text()
+    content = (app.outdir / '1' / 'python.1').read_text()
     assert 'This is a rubric\n' in content
