@@ -4,15 +4,15 @@
 
     Test the Theme class.
 
-    :copyright: Copyright 2007-2020 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
 import os
 
 import alabaster
-
 import pytest
+
 from sphinx.theming import ThemeError
 
 
@@ -74,14 +74,14 @@ def test_js_source(app, status, warning):
 
     app.builder.build(['contents'])
 
-    v = '3.4.1'
+    v = '3.5.1'
     msg = 'jquery.js version does not match to {v}'.format(v=v)
     jquery_min = (app.outdir / '_static' / 'jquery.js').read_text()
     assert 'jQuery v{v}'.format(v=v) in jquery_min, msg
     jquery_src = (app.outdir / '_static' / 'jquery-{v}.js'.format(v=v)).read_text()
     assert 'jQuery JavaScript Library v{v}'.format(v=v) in jquery_src, msg
 
-    v = '1.3.1'
+    v = '1.12.0'
     msg = 'underscore.js version does not match to {v}'.format(v=v)
     underscore_min = (app.outdir / '_static' / 'underscore.js').read_text()
     assert 'Underscore.js {v}'.format(v=v) in underscore_min, msg
@@ -127,7 +127,7 @@ def test_dark_style(app, status, warning):
     assert (app.outdir / '_static' / 'pygments_dark.css').exists()
 
     result = (app.outdir / 'index.html').read_text()
-    assert '<link rel="stylesheet" href="_static/pygments.css" type="text/css" />' in result
+    assert '<link rel="stylesheet" type="text/css" href="_static/pygments.css" />' in result
     assert ('<link id="pygments_dark_css" media="(prefers-color-scheme: dark)" '
             'rel="stylesheet" type="text/css" '
             'href="_static/pygments_dark.css" />') in result
